@@ -46,7 +46,7 @@ class GraphSettings:
     def subgraph_view(self, graph) -> networkx.MultiDiGraph:
         view = networkx.MultiDiGraph(name="template")
         resources: List[str] = [
-            n for n, v in graph.nodes.items() if v["type"] in ["Resource"]
+            n for n, v in graph.nodes.items() if v["type"] in ['"Resource"']
         ]
         view.add_nodes_from((n, graph.nodes[n]) for n in resources)
         view.add_edges_from(
@@ -247,7 +247,7 @@ class Graph:
             label=label,
             color=settings.color,
             shape=settings.shape,
-            type=settings.node_type,
+            type=f'"{settings.node_type}"',
         )
 
     def _add_edge(self, source_id, target_id, source_path, settings):
@@ -261,6 +261,8 @@ class Graph:
 
     def _is_resource(self, cfn, identifier):
         """Check if the identifier is that of a Resource"""
+        if not isinstance(identifier, str):
+            return None
         return cfn.template.get("Resources", {}).get(identifier, {})
 
     def _find_parameter(self, string):
