@@ -2,11 +2,12 @@
 Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
+
 from __future__ import annotations
 
 import logging
 from copy import deepcopy
-from typing import List, Union
+from typing import Any, Dict, List, Union
 
 import regex as re
 
@@ -19,6 +20,94 @@ from cfnlint.template.transforms import Transform
 LOGGER = logging.getLogger(__name__)
 
 
+def resolve_pointer(obj, pointer) -> Dict:
+    """Find the elements at the end of a Cfn pointer
+
+    Args:
+        obj (dict): the root schema used for searching for the pointer
+        pointer (str): the pointer using / to separate levels
+    Returns:
+        Dict: returns the object from the pointer
+    """
+    json_pointer = _SchemaPointer(obj, pointer)
+    return json_pointer.resolve()
+
+
+class _SchemaPointer:
+    def __init__(self, obj: dict, pointer: str) -> None:
+        self.obj = obj
+        self.parts = pointer.split("/")[1:]
+
+    def resolve(self) -> Dict:
+        """Find the elements at the end of a Cfn pointer
+
+        Args:
+        Returns:
+            Dict: returns the object from the pointer
+        """
+        obj = self.obj
+        for part in self.parts:
+            try:
+                obj = self.walk(obj, part)
+            except KeyError as e:
+                raise e
+
+        if "*" in self.parts:
+            return {"type": "array", "items": obj}
+
+        return obj
+
+    # pylint: disable=too-many-return-statements
+    def walk(self, obj: Dict, part: str) -> Any:
+        """Walks one step in doc and returns the referenced part
+
+        Args:
+            obj (dict): the object to evaluate for the part
+            part (str): the string representation of the part
+        Returns:
+            Dict: returns the object at the part
+        """
+        assert hasattr(obj, "__getitem__"), f"invalid document type {type(obj)}"
+
+        try:
+            # using a test for typeName as that is a root schema property
+            if part == "properties" and obj.get("typeName"):
+                return obj[part]
+            if (
+                obj.get("properties")
+                and part != "definitions"
+                and not obj.get("typeName")
+            ):
+                return obj["properties"][part]
+            # arrays have a * in the path
+            if part == "*" and obj.get("type") == "array":
+                return obj.get("items")
+            return obj[part]
+
+        except KeyError as e:
+            # CFN JSON pointers can go down $ref paths so lets do that if we can
+            if obj.get("$ref"):
+                try:
+                    return resolve_pointer(self.obj, f"{obj.get('$ref')}/{part}")
+                except KeyError as ke:
+                    raise ke
+            if obj.get("items", {}).get("$ref"):
+                ref = obj.get("items", {}).get("$ref")
+                try:
+                    return resolve_pointer(self.obj, f"{ref}/{part}")
+                except KeyError as ke:
+                    raise ke
+            if obj.get("oneOf"):
+                for oneOf in obj.get("oneOf"):  # type: ignore
+                    try:
+                        return self.walk(oneOf, part)
+                    except KeyError:
+                        pass
+
+                raise KeyError(f"No oneOf matches for {part}") from e
+            raise e
+
+
 class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attributes
     """Class for a CloudFormation template"""
 
@@ -93,9 +182,6 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
 
     def has_language_extensions_transform(self):
         """Check if the template has language extensions transform declared"""
-        LOGGER.debug(
-            "Check if the template has language extensions transform declaration"
-        )
         lang_extensions_transform = "AWS::LanguageExtensions"
         transform_declaration = self.transform_pre["Transform"]
         transform_type = (
@@ -105,6 +191,34 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
         )
         return bool(lang_extensions_transform in transform_type)
 
+    def has_serverless_transform(self):
+        """Check if the template has SAM transform declared"""
+        lang_extensions_transform = "AWS::Serverless-2016-10-31"
+        transform_declaration = self.transform_pre["Transform"]
+        transform_type = (
+            transform_declaration
+            if isinstance(transform_declaration, list)
+            else [transform_declaration]
+        )
+        return bool(lang_extensions_transform in transform_type)
+
+    def is_cdk_template(self) -> bool:
+        """Check if the template was created by CDK"""
+        resources = self.template.get("Resources")
+        if not isinstance(resources, dict):
+            return False
+
+        for _, properties in resources.items():
+            if not isinstance(properties, dict):
+                continue
+            resource_type = properties.get("Type")
+            if not isinstance(resource_type, str):
+                continue
+            if resource_type == "AWS::CDK::Metadata":
+                return True
+
+        return False
+
     def get_resources(self, resource_type=[]):
         """
         Get Resources
@@ -237,6 +351,47 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
             results[pseudoparam] = element
         return results
 
+    def _get_valid_getatts_from_schema(self, schema, pointer):
+        results = {}
+        try:
+            item = resolve_pointer(schema, pointer)
+        except KeyError:
+            return results
+
+        pointer = pointer.replace("/properties/", "").replace("#/definitions/", "")
+
+        item_type = item.get("type")
+        if item_type is None:
+            if "$ref" in item:
+                results.update(
+                    self._get_valid_getatts_from_schema(schema, item.get("$ref"))
+                )
+            else:
+                return results
+        _type = None
+        primitive_type = None
+        if item_type == "string":
+            primitive_type = "String"
+        elif item_type == "number":
+            primitive_type = "Double"
+        elif item_type == "integer":
+            primitive_type = "Integer"
+        elif item_type == "boolean":
+            primitive_type = "Boolean"
+        elif item_type == "array":
+            _type = "List"
+            primitive_type = "String"
+
+        results[".".join(pointer.split("/"))] = {}
+        if _type:
+            results[".".join(pointer.split("/"))]["Type"] = _type
+            results[".".join(pointer.split("/"))]["PrimitiveItemType"] = primitive_type
+        elif primitive_type:
+            results[".".join(pointer.split("/"))]["PrimitiveType"] = primitive_type
+
+        return results
+
+    # pylint: disable=too-many-locals
     def get_valid_getatts(self):
         resourcetypes = cfnlint.helpers.RESOURCE_SPECS["us-east-1"].get("ResourceTypes")
         propertytypes = cfnlint.helpers.RESOURCE_SPECS["us-east-1"].get("PropertyTypes")
@@ -268,16 +423,10 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
                 valtype = value["Type"]
                 if isinstance(valtype, str):
                     if valtype.startswith(astrik_string_types):
-                        LOGGER.debug(
-                            "Cant build an appropriate getatt list from %s", valtype
-                        )
                         results[name] = {"*": {"PrimitiveItemType": "String"}}
                     elif valtype.startswith(astrik_unknown_types) or valtype.endswith(
                         "::MODULE"
                     ):
-                        LOGGER.debug(
-                            "Cant build an appropriate getatt list from %s", valtype
-                        )
                         results[name] = {"*": {}}
                     else:
                         if value["Type"] in resourcetypes:
@@ -305,6 +454,15 @@ class Template:  # pylint: disable=R0904,too-many-lines,too-many-instance-attrib
                                         element = {}
                                         element.update(attvalue)
                                         results[name][attname] = element
+                        for schema in cfnlint.helpers.REGISTRY_SCHEMAS:
+                            if value["Type"] == schema["typeName"]:
+                                results[name] = {}
+                                for ro_property in schema.get("readOnlyProperties", []):
+                                    results[name].update(
+                                        self._get_valid_getatts_from_schema(
+                                            schema, ro_property
+                                        )
+                                    )
 
         return results
 
